Module: NdrWorkflow

Defined in:
lib/ndr_workflow.rb,
lib/ndr_workflow/engine.rb,
lib/ndr_workflow/version.rb,
lib/ndr_workflow/e_action_progress.rb

Overview

NdrWorkflow

Defined Under Namespace

Modules: EActionProgress Classes: Engine

Constant Summary collapse

VERSION =
'1.2.5'

Class Method Summary collapse

Class Method Details

.migration_classObject

Rails 5 uses versioned migrations (required as of 5.1). This helper method returns an appropriate migration superclass for the Rails version of the host application. Note that the 4.2 compatability layer is targetted since all the bundled migrations were written prior to Rails 5.



16
17
18
# File 'lib/ndr_workflow.rb', line 16

def self.migration_class
  Rails::VERSION::MAJOR < 5 ? ActiveRecord::Migration : ActiveRecord::Migration[4.2]
end